=======
History
=======

0.3.0 (2018-03-16)
------------------

* Add command line interface

0.2.1 (2018-03-16)
------------------

* Re-package everything following the 2Scoops course `Creating and Distributing Python Packages`_.

.. _Creating and Distributing Python Packages: https://courses.twoscoopspress.com/courses/take/creating-and-distributing-python-packages/

0.2.0 (2017-04-15)
------------------
* 4-digit codes return places if exist.

0.1.5 (2017-04-06)
------------------
* First release on PyPI.

